@@ -4,6 +4,6 @@ from typing import List
 
 @dataclass
 class ImportGroupData:
-    ldap_group_cn: str
+    ldap_group_dn: str
     users: List[str]
     target_cloudshell_groups: List[str]
